"use strict";

this.author      = "cim"; 
this.copyright   = "2011-2015 cim."; 
this.licence = "CC-BY-SA 3.0";
this.name        = "Rescue Scenario 4"; 
this.description = "This script adds scenario 4 rescue mission."; 

//added long range map to the mission screens -spara-
//fixed description expand bug -spara-

this.scenarioID = "4";

this.startUp = function() {
// make sure Rescue Stations is loaded first
		if (worldScripts["Rescue Stations"].startUp) {
				worldScripts["Rescue Stations"].startUp();
		}
		worldScripts["Rescue Stations"].registerScenario(this.scenarioID);

}

this.missionAvailableCount = function() {
		var mac = Math.floor(Math.sqrt(1+(Math.random()*9))); // probably 1 or 2, rarely 3
		if (mac<1) { return 1; }
		return mac;
}

this.missionAvailable = function() {
		if (missionVariables.rescuestation_reputation < 10) {
				return false; // need some rep to start doing these
		}
		if (player.bounty > 50) {
				return false; // no fugitives
		}
		if (Math.random() > 0.7) {
				return false; // often available
		}
		var nearby = this.targetSystems();
		if (nearby.length == 0) {
				return false; // nowhere suitable (unlikely!)
		}
		return true;
}

this.targetSystems = function() {
		return SystemInfo.filteredSystems(this, function (other) {
				if (!( (other.systemID !== system.info.systemID) && 
						(!other.sun_gone_nova) &&
						(other.government <= 4) && // communist or less
						(system.info.distanceToSystem(other) > 7) &&
							 (system.info.distanceToSystem(other) < 15))) {
						return false;
				} else {
						var route = system.info.routeToSystem(other);
						return (route && route.distance <= 25);
				}
		});
}


this.initMissionVariables = function() {

		missionVariables.rescuestation_system = system.ID;
		missionVariables.rescuestation_system_name = system.name; 
		var systems = this.targetSystems();
		
		var destsystem = systems[Math.floor(Math.random()*systems.length)];
		
		missionVariables.rescuestation_destsystem = destsystem.systemID;
		missionVariables.rescuestation_destsystem_name = destsystem.name;

		var direction = worldScripts["Rescue Stations"].getDirection(system.info,destsystem);
		missionVariables.rescuestation_destsystem_desc = destsystem.name+" ("+expandDescription("[rescue_govname_"+destsystem.government+"]")+", "+Math.round(system.info.distanceToSystem(destsystem))+" LY "+direction+")";

		var deadline = clock.seconds+(3600*system.info.routeToSystem(destsystem).time*(2.2+Math.random()));
		missionVariables.rescuestation_deadline = deadline;
		missionVariables.rescuestation_deadline_text = clock.clockStringForTime(deadline);

		missionVariables.rescuestation_pilot = randomName()+" "+randomName();
		missionVariables.rescuestation_pilotdesc = randomInhabitantsDescription(false);

		var reward = Math.floor((3*system.info.routeToSystem(destsystem).distance-destsystem.government) * 15);

		missionVariables.rescuestation_reward = reward;
}

this.rescue_shipDockedWithStation = function (rstation) {
		
		if (rstation.hasRole("rescue_station") && system.ID == missionVariables.rescuestation_system && missionVariables.rescuestation_stage >= 100) {
				if (clock.seconds < missionVariables.rescuestation_deadline) {
						missionVariables.rescuestation_stage = 1000;
				} else {
						missionVariables.rescuestation_stage = 1001;
				}
		} else if (rstation.isMainStation && system.ID == missionVariables.rescuestation_destsystem && missionVariables.rescuestation_stage < 100) {
				missionVariables.rescuestation_stage = 100;
		}

}

this.rescue_missionScreenOpportunity = function() {
		if (worldScripts["Rescue Stations"].restoreDestination) {
			player.ship.targetSystem = worldScripts["Rescue Stations"].restoreDestination;
			delete worldScripts["Rescue Stations"].restoreDestination;
		}
		if (missionVariables.rescuestation_stage == 1) {
				mission.runScreen ({title: "Personnel recovery needed",
														messageKey: "rescue_scenario_4_mission_available",
														choicesKey: "rescue_scenario_nonurgent_mission_choices_map",
														model: "rescue_station",
														background: "rrsfl_blank_bg.png"},
													 worldScripts["Rescue Scenario "+missionVariables.rescuestation_scenario].missionOfferDecision
													);
		} else if (missionVariables.rescuestation_stage == 1000) {
				var reward = missionVariables.rescuestation_reward;
				player.credits += reward;

				mission.runScreen({title: "Recovery completed",
													 messageKey: "rescue_scenario_4_mission_complete",
													 background: "rrsfl_bg.png"});

				worldScripts["Rescue Stations"].missionSuccess();
		} else if (missionVariables.rescuestation_stage == 1001) {
				var reward = missionVariables.rescuestation_reward;
				player.credits += reward;

				mission.runScreen({title: "Recovery completed",
													 messageKey: "rescue_scenario_4_mission_toolate",
													 background: "rrsfl_bg.png"});

				worldScripts["Rescue Stations"].failMission();

		} else if (missionVariables.rescuestation_stage == 100) {
				mission.runScreen({title: "Pilot rescued",
													 messageKey: "rescue_scenario_4_mission_rescue",
													 model: player.ship.dockedStation.primaryRole,
													 background: "rrsfl_blank_bg.png"});

				mission.unmarkSystem({system: missionVariables.rescuestation_destsystem, name: "RRS"});
				mission.markSystem({system: missionVariables.rescuestation_system, name: "RRS"});

				missionVariables.rescuestation_stage = 101;
		}
}


this.rescue_shipWillLaunchFromStation = function (rstation) {

}


this.rescue_shipExitedWitchspace = function() {
		if (missionVariables.rescuestation_stage < 100 && clock.seconds > missionVariables.rescuestation_deadline) {
				player.commsMessage(missionVariables.rescuestation_system_name+" RRS: We've managed to get commercial transport for "+missionVariables.rescuestation_pilot+". Try to be a bit more prompt in future or there's no point hiring you!");
				worldScripts["Rescue Stations"].failMission();
		}

}

/* Mission setup */

this.missionSuccess = function() {
		missionVariables.rescuestation_reputation += 10;
		// nothing special		
}

this.failMission = function () {
		if (missionVariables.rescuestation_stage > 100) {
				mission.unmarkSystem({system: missionVariables.rescuestation_destsystem, name: "RRS"});
		} else {
				mission.unmarkSystem({system: missionVariables.rescuestation_startsystem, name: "RRS"});
		}
		if (missionVariables.rescuestation_stage != 1001) {
				missionVariables.rescuestation_reputation -= 10; // no rep penalty if they were retrieved
		}
}

this.cleanupMission = function() {
		delete missionVariables.rescuestation_reward;
		delete missionVariables.rescuestation_system;
		delete missionVariables.rescuestation_system_name;
		delete missionVariables.rescuestation_destsystem;
		delete missionVariables.rescuestation_destsystem_name;
		delete missionVariables.rescuestation_destsystem_desc;
		delete missionVariables.rescuestation_deadline;
		delete missionVariables.rescuestation_deadline_text;
		delete missionVariables.rescuestation_pilot;
		delete missionVariables.rescuestation_pilotdesc;
}


this.missionOfferDecision = function (choice) {
		if (choice == "NO") {
				worldScripts["Rescue Stations"].refuseCurrentMission();
				worldScripts["Rescue Stations"].cleanupMission();
				missionVariables.rescuestation_stage = 0;
		} 
		else if (choice === "MAP") {
			worldScripts["Rescue Stations"].restoreDestination = player.ship.targetSystem;
			player.ship.targetSystem = missionVariables.rescuestation_destsystem;
				mission.runScreen ({title: "Personnel recovery needed",
														backgroundSpecial: "LONG_RANGE_CHART_QUICKEST"
														},
														worldScripts["Rescue Scenario "+missionVariables.rescuestation_scenario].rescue_missionScreenOpportunity
													);
		}
		else {
				missionVariables.rescuestation_stage = 2;
				mission.runScreen({title: "Good luck",
													 messageKey: "rescue_scenario_4_mission_accepted",
													 model: "rescue_station",
													 background: "rrsfl_blank_bg.png"},
													function (choice) {
															worldScripts["Rescue Stations"].acceptMission();
															worldScripts["Rescue Stations"].setMissionDetails("rescue_scenario_4_description");
													}
												 );
				mission.markSystem({system: missionVariables.rescuestation_destsystem, name: "RRS"});
				
		}
}

/* Mission functions */

